@@ -2,6 +2,7 @@ import collections
 import enum
 import json
 import uuid
+from functools import lru_cache
 from typing import Dict
 
 from typedpy.commons import (
@@ -33,12 +34,19 @@ from typedpy.structures import (
     Field,
     ClassReference,
 )
-from typedpy.structures.consts import ENABLE_UNDEFINED
+from typedpy.structures.consts import (
+    DESERIALIZATION_MAPPER,
+    ENABLE_UNDEFINED,
+    SERIALIZATION_MAPPER,
+)
 from typedpy.fields import (
+    Enum,
     FunctionCall,
     Number,
     SizedCollection,
     String,
+    Float,
+    Integer,
     StructureReference,
     Array,
     Map,
@@ -58,6 +66,7 @@ from typedpy.fields import (
     _ListStruct,
 )
 
+
 # pylint: disable=too-many-locals, too-many-arguments, too-many-branches
 def deserialize_list_like(
     field,
@@ -471,6 +480,50 @@ def construct_fields_map(
     return result
 
 
+@lru_cache(maxsize=128)
+def _structure_is_simple(cls):
+    for v in cls.get_all_fields_by_name().values():
+        if isinstance(v, (Integer, String, Float, Boolean, NoneField, Enum)):
+            continue
+        if isinstance(v, AnyOf):
+            for f in v.get_fields():
+                if not isinstance(f, (Integer, String, Float, Boolean, NoneField)):
+                    return False
+            continue
+        if isinstance(v, Array):
+            if isinstance(v.items, (Integer, String, Float, Boolean, NoneField)):
+                continue
+            return False
+        return False
+
+    return True
+
+
+@lru_cache(maxsize=128)
+def _get_enum_mapping(cls):
+    return {
+        k: getattr(v, "_enum_class")
+        for k, v in cls.get_all_fields_by_name().items()
+        if isinstance(v, Enum) and getattr(v, "_is_enum", False)
+    }
+
+
+@lru_cache(maxsize=128)
+def _get_class_deserialization_mapping_for_simple_class(cls):
+    mapper = getattr(
+        cls, DESERIALIZATION_MAPPER, getattr(cls, SERIALIZATION_MAPPER, None)
+    )
+    if mapper:
+        resolved_mapper = aggregate_deserialization_mappers(cls)
+        for v in resolved_mapper.values():
+            if not isinstance(v, str):
+                raise ValueError(
+                    f"Mapper {v} is unsupported for trusted deserialization"
+                )
+        return resolved_mapper
+    return None
+
+
 def deserialize_structure_internal(
     cls,
     the_dict,
@@ -479,6 +532,7 @@ def deserialize_structure_internal(
     mapper=None,
     keep_undefined=False,
     camel_case_convert=False,
+    direct_trusted_mapping=False,
 ):
     """
     Deserialize a dict to a Structure instance, Jackson style.
@@ -503,14 +557,39 @@ def deserialize_structure_internal(
         an instance of the provided :class:`Structure` deserialized
     """
 
+    input_dict = the_dict
     if issubclass(cls, Versioned):
         if not isinstance(the_dict, dict) or "version" not in the_dict:
             raise TypeError("Expected a dictionary with a 'version' value")
         if getattr(cls, VERSION_MAPPING):
             versions_mapping = getattr(cls, VERSION_MAPPING)
             input_dict = convert_dict(the_dict, versions_mapping)
-    else:
-        input_dict = the_dict
+
+    if (
+        direct_trusted_mapping
+        and not mapper
+        and _structure_is_simple(cls)
+        and not camel_case_convert
+    ):
+        enum_mapping = _get_enum_mapping(cls)
+        if enum_mapping:
+            enum_vals = {
+                k: mapping[input_dict[k]]
+                for k, mapping in enum_mapping.items()
+                if input_dict.get(k)
+            }
+            input_dict.update(**enum_vals)
+        deserialization_mapper = _get_class_deserialization_mapping_for_simple_class(
+            cls
+        )
+        if deserialization_mapper:
+            input_dict = {
+                k: input_dict[deserialization_mapper[k]]
+                for k in deserialization_mapper
+                if deserialization_mapper[k] in input_dict
+            }
+        return cls.from_trusted_data(input_dict)
+
     mapper = aggregate_deserialization_mappers(cls, mapper, camel_case_convert)
     if keep_undefined:
         for m in cls.get_aggregated_deserialization_mapper():
@@ -541,7 +620,7 @@ def deserialize_structure_internal(
                     ignore_none=ignore_none,
                 )
             )
-        raise TypeError(f"{name}: Expected a dictionary; Got { wrap_val(input_dict)}")
+        raise TypeError(f"{name}: Expected a dictionary; Got {wrap_val(input_dict)}")
 
     kwargs = {
         k: v
@@ -568,7 +647,13 @@ def deserialize_structure_internal(
 
 
 def deserialize_structure(
-    cls, the_dict, *, mapper=None, keep_undefined=True, camel_case_convert=False
+    cls,
+    the_dict,
+    *,
+    mapper=None,
+    keep_undefined=True,
+    camel_case_convert=False,
+    direct_trusted_mapping=False,
 ):
     """
     Deserialize a dict to a Structure instance, Jackson style.
@@ -598,6 +683,7 @@ def deserialize_structure(
         mapper=mapper,
         keep_undefined=keep_undefined,
         camel_case_convert=camel_case_convert,
+        direct_trusted_mapping=direct_trusted_mapping,
     )
 
 
@@ -828,7 +914,7 @@ def serialize_internal(
         else [
             (k, v)
             for (k, v) in structure.__dict__.items()
-            if k not in ["_instantiated", "_none_fields"]
+            if k not in ["_instantiated", "_none_fields", "_trust_supplied_values"]
         ]
     ) + nones
     props = structure.__class__.__dict__
